## 代码发布规范
版本采用3位版本号的方式

另外版本号的规范给你说下，一般是3位版本号。
如果接口没有什么修改的话，升级最后一位。
如果可以向后兼容的修改，但是接口有更新的话，升级第二位，第3位重置成0
如果无法向后兼容，就直接修改第一位版本号。（这位一般是不动的）

1. 提交新版本时需要打tag
2. 打完tag后立刻更新版本号
3. 首先发布到<https://testpypi.python.org/pypi>, 确定功能正常之后，发布到<https://pypi.python.org/pypi>

## 其他需要注意的
- 尽量不要破坏原有的API
- 文档及时更新
